@@ -1,23 +1,9 @@
 /*
+ * oFono - Open Source Telephony
+ * Copyright (C) 2008-2011  Intel Corporation
+ * Copyright (C) 2011  ST-Ericsson AB
  *
- *  oFono - Open Source Telephony
- *
- *  Copyright (C) 2008-2011  Intel Corporation. All rights reserved.
- *  Copyright (C) 2011  ST-Ericsson AB.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License version 2 as
- *  published by the Free Software Foundation.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #ifdef HAVE_CONFIG_H
@@ -35,10 +21,11 @@
 #include <ofono/modem.h>
 #include <ofono/gnss.h>
 
+#include <drivers/atmodem/atutil.h>
+
 #include "gatchat.h"
 #include "gatresult.h"
 
-#include "atmodem.h"
 #include "vendor.h"
 
 struct gnss_data {
@@ -263,19 +250,10 @@ static void at_gnss_remove(struct ofono_gnss *gnss)
 }
 
 static const struct ofono_gnss_driver driver = {
-	.name			= "atmodem",
 	.probe			= at_gnss_probe,
 	.remove			= at_gnss_remove,
 	.send_element		= at_gnss_send_element,
 	.set_position_reporting	= at_gnss_position_reporting,
 };
 
-void at_gnss_init(void)
-{
-	ofono_gnss_driver_register(&driver);
-}
-
-void at_gnss_exit(void)
-{
-	ofono_gnss_driver_unregister(&driver);
-}
+OFONO_ATOM_DRIVER_BUILTIN(gnss, atmodem, &driver)
