@@ -2,7 +2,7 @@
  *
  *  oFono - Open Source Telephony
  *
- *  Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
+ *  Copyright (C) 2009-2010  Nokia Corporation and/or its subsidiary(-ies).
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -23,7 +23,6 @@
 #include <config.h>
 #endif
 
-#define _GNU_SOURCE
 #include <stdint.h>
 #include <string.h>
 #include <sys/types.h>
@@ -34,6 +33,9 @@
 #include <errno.h>
 #include <glib.h>
 
+#pragma GCC diagnostic ignored "-Wpragmas"
+#pragma GCC diagnostic ignored "-Waddress-of-packed-member"
+
 #include "message.h"
 #include "common.h"
 #include "modem.h"
@@ -163,7 +165,8 @@ static void pending_remove_and_dispatch(GIsiPending *op, GIsiMessage *msg)
 	modem = op->service->modem;
 
 	ISIDBG(modem, "%s %s to %p [res=0x%02X, id=0x%02X, utid=0x%02X]",
-		g_isi_msg_strerror(msg), pend_type_to_str(op->type), op,
+		g_isi_msg_error(msg) ? g_isi_msg_strerror(msg) : "normal",
+		pend_type_to_str(op->type), op,
 		g_isi_msg_resource(msg), g_isi_msg_id(msg),
 		g_isi_msg_utid(msg));
 
